import { Directive, ElementRef, HostBinding, Inject, Input, NgModule } from '@angular/core';
import { BoundSensor, BoundSensorDefaultOptions } from 'bound-sensor';

/**
 * @license AngularBoundSensor v1.0.8
 * (c) 2017 Amin Paks <amin.pakseresht@hotmail.com>
 * License: MIT
 */
class BoundSensorDirective {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this._hostPositionStyle = '';
        this._hostDisplayStyle = '';
        this._element = elementRef.nativeElement;
        this._options = Object.assign({}, BoundSensorDefaultOptions, { attachToParent: false });
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.updateHostStyles();
        const /** @type {?} */ host = this._options.attachToParent === true ? this._element.parentElement : this._element;
        this._sensor = new BoundSensor(/** @type {?} */ (Object.assign({}, this._options, { modifyStyles: false })));
        this._sensor.attachSensor(host);
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        const /** @type {?} */ options = changes['boundSensor'];
        if (options) {
            const /** @type {?} */ newOptions = options.currentValue;
            if (options.firstChange === true) {
                if (typeof newOptions.debounceTime === 'number') {
                    this._options.debounceTime = newOptions.debounceTime;
                }
                if (typeof newOptions.eventName === 'string') {
                    this._options.eventName = newOptions.eventName;
                }
                if (typeof newOptions.modifyStyles === 'boolean') {
                    this._options.modifyStyles = newOptions.modifyStyles;
                }
                if (typeof newOptions.attachToParent === 'boolean') {
                    this._options.attachToParent = newOptions.attachToParent;
                }
            }
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.removeHostStyles();
        this._sensor.detachSensor();
    }
    /**
     * @return {?}
     */
    updateHostStyles() {
        if (this._options.modifyStyles === true) {
            if (this._options.attachToParent === false) {
                this._hostDisplayStyle = 'block';
                this._hostPositionStyle = 'relative';
            }
            else {
                this._element.parentElement.style.display = 'block';
                this._element.parentElement.style.position = 'relative';
            }
        }
    }
    /**
     * @return {?}
     */
    removeHostStyles() {
        if (this._options.modifyStyles === true) {
            if (this._options.attachToParent === false) {
                this._hostDisplayStyle = '';
                this._hostPositionStyle = '';
            }
            else {
                this._element.parentElement.style.display = '';
                this._element.parentElement.style.position = '';
            }
        }
    }
}
BoundSensorDirective.decorators = [
    { type: Directive, args: [{
                selector: '[boundSensor]',
            },] },
];
/**
 * @nocollapse
 */
BoundSensorDirective.ctorParameters = () => [
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] },] },
];
BoundSensorDirective.propDecorators = {
    'boundSensor': [{ type: Input },],
    '_hostDisplayStyle': [{ type: HostBinding, args: ['style.display',] },],
    '_hostPositionStyle': [{ type: HostBinding, args: ['style.position',] },],
};

class BoundSensorModule {
}
BoundSensorModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    BoundSensorDirective,
                ],
                exports: [
                    BoundSensorDirective,
                ],
            },] },
];
/**
 * @nocollapse
 */
BoundSensorModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { BoundSensorModule, BoundSensorDirective };
//# sourceMappingURL=angular-bound-sensor.js.map
