(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('bound-sensor')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', 'bound-sensor'], factory) :
	(factory((global['angular-bound-sensor'] = {}),global.ng.core,global.boundSensor));
}(this, (function (exports,_angular_core,boundSensor) { 'use strict';

/**
 * @license AngularBoundSensor v1.0.8
 * (c) 2017 Amin Paks <amin.pakseresht@hotmail.com>
 * License: MIT
 */
var BoundSensorDirective = (function () {
    /**
     * @param {?} elementRef
     */
    function BoundSensorDirective(elementRef) {
        this._hostPositionStyle = '';
        this._hostDisplayStyle = '';
        this._element = elementRef.nativeElement;
        this._options = Object.assign({}, boundSensor.BoundSensorDefaultOptions, { attachToParent: false });
    }
    /**
     * @return {?}
     */
    BoundSensorDirective.prototype.ngOnInit = function () {
        this.updateHostStyles();
        var /** @type {?} */ host = this._options.attachToParent === true ? this._element.parentElement : this._element;
        this._sensor = new boundSensor.BoundSensor(/** @type {?} */ (Object.assign({}, this._options, { modifyStyles: false })));
        this._sensor.attachSensor(host);
    };
    /**
     * @param {?} changes
     * @return {?}
     */
    BoundSensorDirective.prototype.ngOnChanges = function (changes) {
        var /** @type {?} */ options = changes['boundSensor'];
        if (options) {
            var /** @type {?} */ newOptions = options.currentValue;
            if (options.firstChange === true) {
                if (typeof newOptions.debounceTime === 'number') {
                    this._options.debounceTime = newOptions.debounceTime;
                }
                if (typeof newOptions.eventName === 'string') {
                    this._options.eventName = newOptions.eventName;
                }
                if (typeof newOptions.modifyStyles === 'boolean') {
                    this._options.modifyStyles = newOptions.modifyStyles;
                }
                if (typeof newOptions.attachToParent === 'boolean') {
                    this._options.attachToParent = newOptions.attachToParent;
                }
            }
        }
    };
    /**
     * @return {?}
     */
    BoundSensorDirective.prototype.ngOnDestroy = function () {
        this.removeHostStyles();
        this._sensor.detachSensor();
    };
    /**
     * @return {?}
     */
    BoundSensorDirective.prototype.updateHostStyles = function () {
        if (this._options.modifyStyles === true) {
            if (this._options.attachToParent === false) {
                this._hostDisplayStyle = 'block';
                this._hostPositionStyle = 'relative';
            }
            else {
                this._element.parentElement.style.display = 'block';
                this._element.parentElement.style.position = 'relative';
            }
        }
    };
    /**
     * @return {?}
     */
    BoundSensorDirective.prototype.removeHostStyles = function () {
        if (this._options.modifyStyles === true) {
            if (this._options.attachToParent === false) {
                this._hostDisplayStyle = '';
                this._hostPositionStyle = '';
            }
            else {
                this._element.parentElement.style.display = '';
                this._element.parentElement.style.position = '';
            }
        }
    };
    return BoundSensorDirective;
}());
BoundSensorDirective.decorators = [
    { type: _angular_core.Directive, args: [{
                selector: '[boundSensor]',
            },] },
];
/**
 * @nocollapse
 */
BoundSensorDirective.ctorParameters = function () { return [
    { type: _angular_core.ElementRef, decorators: [{ type: _angular_core.Inject, args: [_angular_core.ElementRef,] },] },
]; };
BoundSensorDirective.propDecorators = {
    'boundSensor': [{ type: _angular_core.Input },],
    '_hostDisplayStyle': [{ type: _angular_core.HostBinding, args: ['style.display',] },],
    '_hostPositionStyle': [{ type: _angular_core.HostBinding, args: ['style.position',] },],
};
var BoundSensorModule = (function () {
    function BoundSensorModule() {
    }
    return BoundSensorModule;
}());
BoundSensorModule.decorators = [
    { type: _angular_core.NgModule, args: [{
                declarations: [
                    BoundSensorDirective,
                ],
                exports: [
                    BoundSensorDirective,
                ],
            },] },
];
/**
 * @nocollapse
 */
BoundSensorModule.ctorParameters = function () { return []; };

exports.BoundSensorModule = BoundSensorModule;
exports.BoundSensorDirective = BoundSensorDirective;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=angular-bound-sensor.umd.js.map
